from distutils.core import setup
setup(
  name = 'cheeseoyes',         
  packages = ['cheeseoyes'],   
  version = '0.1',      
  license='LICENSE.txt',        
  description = '',   
  author = 'oliverstech',                   
  author_email = 'mail@oliverstech.tk',      
  url = 'http://oliverstech.tk',   
  install_requires=[''],
  classifiers=[
    'Development Status :: 3 - Alpha',      
    'Intended Audience :: Developers',      
    'Topic :: Software Development :: Build Tools',
    'Programming Language :: Python :: 3',      
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
